<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xpath-default-namespace="http://www.tei-c.org/ns/1.0"
    exclude-result-prefixes="xs"
    version="2.0">
<!--    Gephi-Tabellen: 
    nodes.csv mit id, label und weiteren Infos aus personen.xml, Briefe, 
    
    file:/Z:/Documents/uni/HistInf/ide/SummerSchoolDigEd/1810Wien-Fortgeschritten/Gephi/gephi.xsl
    -->
    <xsl:variable name="personen" select="doc('../berliner-intellektuelle-indexes/xml/Personenindex.xml')"/>
    <xsl:variable name="werke" select="doc('../berliner-intellektuelle-indexes/xml/Werkindex.xml')"/>
    <xsl:variable name="org" select="doc('../berliner-intellektuelle-indexes/xml/Gruppenindex.xml')"/>
    <xsl:template match="/">
        <xsl:result-document href="gephi/letters.csv" method="text" byte-order-mark="true" encoding="utf-8">
            <!-- Knoten mit id, label, type -->
            <xsl:text>id;label;date;typ</xsl:text>
            <!-- Briefe: -->
            <xsl:apply-templates select="//TEI"/>
        </xsl:result-document>
        <xsl:result-document href="gephi/persons.csv" method="text" byte-order-mark="true" encoding="utf-8">
            <!-- Knoten mit id, label, type -->
            <xsl:text>id;label;date;typ</xsl:text>
            <!-- Personen: -->
            <xsl:apply-templates select="$personen//person"/>
        </xsl:result-document>
        <xsl:result-document href="gephi/groups.csv" method="text" byte-order-mark="true" encoding="utf-8">
            <!-- Knoten mit id, label, type -->
            <xsl:text>id;label;date;typ</xsl:text>
            <!-- Organisationen:  -->
            <xsl:apply-templates select="$org//org"/>
        </xsl:result-document>
            <!-- Werke: -->
<!--            <xsl:apply-templates select="$werke//biblStruct"/>-->
        <xsl:result-document href="gephi/egdes.csv" method="text" byte-order-mark="true" encoding="utf-8">
            <xsl:text>source;target;attribute</xsl:text>
            <!-- Kanten: id, source, target, attribute
            Brief-Person
            Brief-Orga
            Brief-Werk
            Orga-Person
            Person-Person via Relation
            -->
<!--            Brief-Person-->
            <xsl:apply-templates select="//text//persName[@ref]|//correspDesc//persName[@ref]"/>
<!--            Brief-Orga-->
            <xsl:apply-templates select="//text//orgName[@ref]|//correspDesc//orgName[@ref]"/>
            <!--            Brief-Werk-->
            <xsl:apply-templates select="//text//*[starts-with(@ref,'#w')]"/>
            <!--            Orga-Person-->
            <xsl:apply-templates select="$org//org" mode="org-pers"/>
            <!-- Person-Person  -->
<!--            <xsl:apply-templates select="$personen//relation"/>-->
        </xsl:result-document>
    </xsl:template>
    
    <!-- Kanten -->
    <xsl:template match="relation">
        <!--<xsl:choose>
    <xsl:when test="@active"></xsl:when>
    <xsl:otherwise>
        <xsl:variable name="all" select="tokenize(@mutual/substring-after(.,'#'))"/>
        <xsl:for-each select="$all">
            <xsl:variable name="me" select="."/>
            <xsl:for-each select="$all"><xsl:text>
</xsl:text>
<!-\-                <xsl:if test="./string() != $me/string()"><xsl:value-of select="."/><xsl:text>;</xsl:text></xsl:if>-\->
            </xsl:for-each>
        </xsl:for-each>
    </xsl:otherwise>
</xsl:choose>-->
    </xsl:template>
    <xsl:template match="*[starts-with(@ref,'w')]">
        <xsl:text>
</xsl:text><xsl:value-of select="ancestor::TEI/@n"/><xsl:text>;</xsl:text><xsl:value-of select="substring-after(@ref,'#')"/><xsl:text>;is mentioned</xsl:text>
    </xsl:template>
    <xsl:template match="persName">
        <xsl:text>
</xsl:text>
        <xsl:value-of select="(ancestor::TEI/@n|ancestor::org/@xml:id)"/>
        <xsl:text>;</xsl:text>
        <xsl:value-of select="substring-after(@ref,'#')"/>
        <xsl:text>;</xsl:text><xsl:value-of select="ancestor::correspAction/@type"/>
    </xsl:template>
    <xsl:template match="orgName">
        <xsl:text>
</xsl:text>
        <xsl:value-of select="ancestor::TEI/@n"/>
        <xsl:text>;</xsl:text>
        <xsl:value-of select="substring-after(@ref,'#')"/>
        <xsl:text>;</xsl:text><xsl:value-of select="ancestor::correspAction/@type"/>
    </xsl:template>
    <xsl:template match="org" mode="org-pers">
        <xsl:for-each select="persName[@ref]">
            <xsl:text>
</xsl:text>
            <xsl:value-of select="ancestor::org/@xml:id"/>
            <xsl:text>;</xsl:text>
            <xsl:value-of select="substring-after(@ref,'#')"/>
            <xsl:text>;is part of</xsl:text>
        </xsl:for-each>
    </xsl:template>
    
    
    <!-- Knoten: -->
    <xsl:template match="TEI[@n]">
        <xsl:text>
</xsl:text><xsl:value-of select="@n"/><xsl:text>;</xsl:text><xsl:value-of select=".//titleStmt/title[1]/normalize-space(replace(translate(string(),'&quot;',''),';', ','))"/><xsl:text>;</xsl:text><xsl:value-of select=".//msDesc//docDate/(@when|@when-iso)"/><xsl:text>;brief</xsl:text>
    </xsl:template>
    <xsl:template match="person">
        <xsl:text>
</xsl:text><xsl:value-of select="@xml:id"/><xsl:text>;</xsl:text><xsl:value-of select="persName[1]/normalize-space(translate(replace(string(),'&quot;',''),';',','))"/><xsl:text>;</xsl:text><xsl:value-of select="death/date/(@when|@when-iso)"/><xsl:text>;person</xsl:text>
    </xsl:template>
    <xsl:template match="org">
        <xsl:text>
</xsl:text><xsl:value-of select="@xml:id"/><xsl:text>;</xsl:text><xsl:value-of select="orgName[1]/normalize-space(replace(translate(string(),'&quot;',''),';', ','))"/><xsl:text>;</xsl:text><xsl:value-of select=".//date[1]/@when-iso"/><xsl:text>;gruppe</xsl:text>
    </xsl:template>
    <xsl:template match="biblStruct">
            <xsl:text>
</xsl:text><xsl:value-of select="@xml:id"/><xsl:text>;</xsl:text><xsl:value-of select="concat(string-join(monogr/author/normalize-space(), ', '), ': ',string-join(monogr/title/normalize-space(), '.'))"/><xsl:text>;</xsl:text><xsl:value-of select="monogr/imprint/date/@when-iso"/><xsl:text>;werk</xsl:text>
    </xsl:template>
</xsl:stylesheet>